#
# spec file for package python-cmd2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-cmd2
Version:        0.7.9
Release:        lp151.2.2
Summary:        Extra features for standard library's cmd module
License:        MIT
Group:          Development/Languages/Python
Url:            http://packages.python.org/cmd2/
Source:         https://files.pythonhosted.org/packages/source/c/cmd2/cmd2-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Requires:       python-pyparsing >= 2.0.1
Requires:       python-pyperclip
Requires:       python-six
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
Enhancements for standard library's cmd module.

Drop-in replacement adds several features for command-prompt tools:

    * Searchable command history (commands: "hi", "li", "run")
    * Load commands from file, save to file, edit commands in file
    * Multi-line commands
    * Case-insensitive commands
    * Special-character shortcut commands (beyond cmd's "@" and "!")
    * Settable environment parameters
    * Parsing commands with flags
    * > (filename), >> (filename) redirect output to file
    * < (filename) gets input from file
    * bare >, >>, < redirect to/from paste buffer
    * accepts abbreviated commands when unambiguous
    * `py` enters interactive Python console
    * test apps against sample session transcript (see example/example.py)

%prep
%setup -q -n cmd2-%{version}

%build
%python_build

%install
%python_install

%files %{python_files}
%defattr(-,root,root,-)
%doc README.md LICENSE
%{python_sitelib}/*

%changelog
* Tue Feb 13 2018 dmueller@suse.com
- update to 0.7.9:
  * Bug Fixes
  * Fixed a couple broken examples
  * Enhancements
  * Improved documentation for modifying shortcuts (command aliases)
  * Made ``pyreadline`` a dependency on Windows to ensure tab-completion works
  * Other changes
  * Abandoned official support for Python 3.3.  It should still work, just don't have an easy way to test it anymore.
  * Bug Fixes
  * Fixed ``poutput()`` so it can print an integer zero and other **falsy** things
  * Fixed a bug which was causing autodoc to fail for building docs on Readthedocs
  * Fixed bug due to ``pyperclip`` dependency radically changing its project structure in latest version
  * Enhancements
  * Improved documentation for user-settable environment parameters
  * Improved documentation for overriding the default supported comment styles
  * Added ``runcmds_plus_hooks()`` method to run multiple commands w/o a cmdloop
  * Bug Fixes
  * Added workaround for bug which occurs in Python 2.7 on Linux when ``pygtk`` is installed
  * ``pfeedback()`` now honors feedback_to_output setting and won't redirect when it is ``False``
  * For ``edit`` command, both **editor** and **filename** can now have spaces in the name/path
  * Fixed a bug which occurred when stdin was a pipe instead of a tty due to input redirection
  * Enhancements
  * ``feedback_to_output`` now defaults to ``False`` so info like command timing won't redirect
  * Transcript regular expressions now have predictable, tested, and documented behavior
  * This makes a breaking change to the format and expectations of transcript testing
  * The prior behavior removed whitespace before making the comparison, now whitespace must match exactly
  * Prior version did not allow regexes with whitespace, new version allows any regex
  * Improved display for ``load`` command and input redirection when **echo** is ``True``
  * Bug Fixes
  * Case-sensitive command parsing was completely broken and has been fixed
  * ``<Ctrl>+d`` now properly quits when case-sensitive command parsing is enabled
  * Fixed some pyperclip clipboard interaction bugs on Linux
  * Fixed some timing bugs when running unit tests in parallel by using monkeypatch
  * Enhancements
  * Enhanced tab-completion of cmd2 command names to support case-insensitive completion
  * Added an example showing how to remove unused commands
  * Improved how transcript testing handles prompts with ANSI escape codes by stripping them
  * Greatly improved implementation for how command output gets piped to a shell command
* Mon Aug  7 2017 tbechtold@suse.com
- convert to singlespec
* Mon Aug  7 2017 tbechtold@suse.com
- update to 0.7.5:
  * `case_insensitive` is no longer a runtime-settable parameter, but it was still listed as such
  * Fixed a recursive loop bug when abbreviated commands are enabled and it could get stuck in the editor forever
  * Fixed argparse_example.py and pirate.py examples and transcript_regex.txt transcript
  * Fixed a bug in a unit test which occurred under unusual circumstances
  * Organized all attributes used to configure the ParserManager into a single location
  * Set the default value of `abbrev` to `False` (which controls whether or not abbreviated commands are allowed)
  * Improved implementation of `load` to use command queue instead of nested inner loop
  * Fixed a couple bugs in interacting with pastebuffer/clipboard on macOS and Linux
  * Fixed a couple bugs in edit and save commands if called when history is empty
  * Ability to pipe ``cmd2`` command output to a shell command is now more reliable, particularly on Windows
  * Fixed a bug in ``pyscript`` command on Windows related to ``\`` being interpreted as an escape
  * Ensure that path and shell command tab-completion results are alphabetically sorted
  * Removed feature for load command to load scripts from URLS
  * Removed presence of a default file name and default file extension
  * ``load`` command has better error checking and reporting
  * Clipboard copy and paste functionality is now handled by the **pyperclip** module
  * ``shell`` command now supports redirection and piping of output
  * Added a lot of unit tests
  * Removed pause command
  * Added a dependency on the **pyperclip** module
  * Fixed a bug in displaying a span of history items when only an end index is supplied
  * Fixed a bug which caused transcript test failures to display twice
  * Added the ability to exclude commands from the help menu (**eof** included by default)
  * Redundant **list** command removed and features merged into **history** command
  * Added **pyscript** command which supports tab-completion and running Python scripts with arguments
  * Improved tab-completion of file system paths, command names, and shell commands
  * Changed default value of USE_ARG_LIST to True - this affects the beavhior of all **@options** commands
  * Refactored code to encapsulate most of the pyparsing logic into a ParserManager class
  * Added a MANIFEST.ini file to make sure a few extra files get included in the PyPI source distribution
  * ``-`` wasn't being treated as a legal character
  * The allow_cli_args attribute wasn't properly disabling parsing of args at invocation when False
  * py command wasn't allowing scripts which used *cmd* function prior to entering an interactive Python session
  * Don't throw exception when piping output to a shell command
  * Transcript testing now properly calls ``preloop`` before and ``postloop`` after
  * Fixed readline bug related to ANSI color escape codes in the prompt
  * Added CONTRIBUTING.md and CODE_OF_CONDUCT.md files
  * Added unicode parsing unit tests and listed unicode support as a feature when using Python 3
  * Added more examples and improved documentation
  * Added CmdResult namedtumple for returning and storing results
  * Added local file system path completion for ``edit``, ``load``, ``save``, and ``shell`` commands
  * Add shell command completion for ``shell`` command or ``!`` shortcut
  * Abbreviated multiline commands are no longer allowed (they never worked correctly anyways)
  * Refactored to use six module for a unified codebase which supports both Python 2 and Python 3
  * Stabilized on all platforms (Windows, Mac, Linux) and all supported Python versions (2.7, 3.3, 3.4, 3.5, 3.6, PyPy)
  * Added lots of unit tests and fixed a number of bugs
  * Improved documentation and moved it to cmd2.readthedocs.io
* Mon Nov 14 2016 dmueller@suse.com
- update to 0.6.9:
  * Support Python 3 input()
* Fri Jan  9 2015 dmueller@suse.com
- update to 0.6.8:
  * In case when which is not installed, do not launch an editor
* Fri Sep 27 2013 dmueller@suse.com
- update to 0.6.7:
  * various python 3.x compat fixes
- remove cmd2-pyparsing201.patch, merged upstream
* Tue Sep 17 2013 speilicke@suse.com
- Add cmd2-pyparsing201.patch: Allow running with pyparsing>=2.0.1
* Tue Sep  3 2013 dmueller@suse.com
- update to 0.6.6.1:
  * go back to pyparsing 1.5.7
* Tue Aug 13 2013 dmueller@suse.com
- update to 0.6.6:
  * include editor search stderr fix
* Thu Jul 25 2013 dheidler@suse.de
- Backport editor stderr fix
* Mon Apr 29 2013 dmueller@suse.com
- update to 0.6.5.1:
  * Fix requires to python-pyparsing
* Fri Jan 11 2013 p.drouand@gmail.com
- Add python3 support
* Fri Jul 27 2012 saschpe@suse.de
- Initial version
